@@ -1,6 +1,6 @@
 package Map::Tube::Node;
 
-$Map::Tube::Node::VERSION   = '3.18';
+$Map::Tube::Node::VERSION   = '3.19';
 $Map::Tube::Node::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,12 +9,13 @@ Map::Tube::Node - Class to represent the station in the map.
 
 =head1 VERSION
 
-Version 3.18
+Version 3.19
 
 =cut
 
 use 5.006;
 use Data::Dumper;
+use Map::Tube::Types qw(Lines);
 
 use Moo;
 use namespace::clean;
@@ -24,7 +25,7 @@ use overload q{""} => 'as_string', fallback => 1;
 has id   => (is => 'ro', required => 1);
 has name => (is => 'ro', required => 1);
 has link => (is => 'ro', required => 1);
-has line => (is => 'rw', required => 1);
+has line => (is => 'rw', isa => Lines, required => 1);
 
 sub as_string {
     my ($self) = @_;
@@ -84,7 +85,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Map-Tube>
+L<https://github.com/manwar/Map-Tube>
 
 =head1 BUGS
 
